{-# LANGUAGE QuasiQuotes       #-}


module BinaryDownloads where

import           GHCup.Types
import           GHCup.Utils.Prelude

import           Data.String.QQ
import           HPath
import           URI.ByteString.QQ

import qualified Data.Map                      as M


    -----------------
    --[ GHC 8.4.4 ]--
    -----------------


ghc_844_64_fedora :: DownloadInfo
ghc_844_64_fedora = DownloadInfo
  [uri|https://downloads.haskell.org/~ghc/8.4.4/ghc-8.4.4-x86_64-fedora27-linux.tar.xz|]
  (Just ([rel|ghc-8.4.4|] :: Path Rel))
  [s|5f871a3eaf808acb2420fdeef9318698|]

ghc_844_64_debian9 :: DownloadInfo
ghc_844_64_debian9 = DownloadInfo
  [uri|https://downloads.haskell.org/~ghc/8.4.4/ghc-8.4.4-x86_64-deb9-linux.tar.xz|]
  (Just ([rel|ghc-8.4.4|] :: Path Rel))
  [s|5f871a3eaf808acb2420fdeef9318698|]

ghc_844_64_debian8 :: DownloadInfo
ghc_844_64_debian8 = DownloadInfo
  [uri|https://downloads.haskell.org/~ghc/8.4.4/ghc-8.4.4-x86_64-deb8-linux.tar.xz|]
  (Just ([rel|ghc-8.4.4|] :: Path Rel))
  [s|5f871a3eaf808acb2420fdeef9318698|]


    -----------------
    --[ GHC 8.6.5 ]--
    -----------------



ghc_865_64_fedora :: DownloadInfo
ghc_865_64_fedora = DownloadInfo
  [uri|https://downloads.haskell.org/~ghc/8.6.5/ghc-8.6.5-x86_64-fedora27-linux.tar.xz|]
  (Just ([rel|ghc-8.6.5|] :: Path Rel))
  [s|5f871a3eaf808acb2420fdeef9318698|]

ghc_865_64_debian9 :: DownloadInfo
ghc_865_64_debian9 = DownloadInfo
  [uri|https://downloads.haskell.org/~ghc/8.6.5/ghc-8.6.5-x86_64-deb9-linux.tar.xz|]
  (Just ([rel|ghc-8.6.5|] :: Path Rel))
  [s|8de779b73c1b2f1b7ab49030015fce3d|]

ghc_865_64_debian8 :: DownloadInfo
ghc_865_64_debian8 = DownloadInfo
  [uri|https://downloads.haskell.org/~ghc/8.6.5/ghc-8.6.5-x86_64-deb8-linux.tar.xz|]
  (Just ([rel|ghc-8.6.5|] :: Path Rel))
  [s|5f871a3eaf808acb2420fdeef9318698|]


    ---------------------
    --[ Cabal-3.0.0.0 ]--
    ---------------------


cabal_3000_64_linux :: DownloadInfo
cabal_3000_64_linux = DownloadInfo
  [uri|https://downloads.haskell.org/~cabal/cabal-install-3.0.0.0/cabal-install-3.0.0.0-x86_64-unknown-linux.tar.xz|]
  Nothing
  [s|32352d2259909970e6ff04faf61bbfac|]



    -------------
    --[ GHCup ]--
    -------------


ghcup_010_64_linux :: DownloadInfo
ghcup_010_64_linux = DownloadInfo [uri|file:///home/ospa_ju/tmp/ghcup-exe|]
                                  Nothing
                                  [s|d8da9e09ca71648f4c1bc6a0a46efc82|]




    -----------------------
    --[ Tarball mapping ]--
    -----------------------


binaryDownloads :: BinaryDownloads
binaryDownloads = M.fromList
  [ ( GHC
    , M.fromList
      [ ( [vver|8.6.5|]
        , VersionInfo [Latest] $ M.fromList
          [ ( A_64
            , M.fromList
              [ (Linux UnknownLinux, M.fromList [(Nothing, ghc_865_64_fedora)])
              , (Linux Ubuntu      , M.fromList [(Nothing, ghc_865_64_debian9)])
              , ( Linux Debian
                , M.fromList
                  [ (Nothing         , ghc_865_64_debian9)
                  , (Just $ [vers|8|], ghc_865_64_debian8)
                  ]
                )
              ]
            )
          ]
        )
      , ( [vver|8.4.4|]
        , VersionInfo [] $ M.fromList
          [ ( A_64
            , M.fromList
              [ (Linux UnknownLinux, M.fromList [(Nothing, ghc_844_64_fedora)])
              , (Linux Ubuntu      , M.fromList [(Nothing, ghc_844_64_fedora)])
              , ( Linux Debian
                , M.fromList
                  [ (Nothing         , ghc_844_64_debian9)
                  , (Just $ [vers|8|], ghc_844_64_debian8)
                  ]
                )
              ]
            )
          ]
        )
      ]
    )
  , ( Cabal
    , M.fromList
      [ ( [vver|3.0.0.0|]
        , VersionInfo [Recommended, Latest] $ M.fromList
          [ ( A_64
            , M.fromList
              [ ( Linux UnknownLinux
                , M.fromList [(Nothing, cabal_3000_64_linux)]
                )
              ]
            )
          ]
        )
      ]
    )
  , ( GHCup
    , M.fromList
      [ ( [vver|0.1.0|]
        , VersionInfo [Latest] $ M.fromList
          [ ( A_64
            , M.fromList
              [(Linux UnknownLinux, M.fromList [(Nothing, ghcup_010_64_linux)])]
            )
          ]
        )
      ]
    )
  ]
